==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AOrBinop.h <==
// public final class soot.jimple.parser.node.AOrBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 439434dedc6b9c37 soot_jimple_parser_node_AOrBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AOrBinop_H_
#define _JC_soot_jimple_parser_node_AOrBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TOr$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AOrBinop$sub_refs	_jc_soot_jimple_parser_node_AOrBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AOrBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AOrBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AOrBinop$refs	_jc_soot_jimple_parser_node_AOrBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AOrBinop$nonrefs	_jc_soot_jimple_parser_node_AOrBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AOrBinop$object	_jc_soot_jimple_parser_node_AOrBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AOrBinop$vmethods	_jc_soot_jimple_parser_node_AOrBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AOrBinop$vtable	_jc_soot_jimple_parser_node_AOrBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AOrBinop$vtype	_jc_soot_jimple_parser_node_AOrBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AOrBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *);
extern void _jc_soot_jimple_parser_node_AOrBinop$method$_init$a9a1f9f4adf55b94(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_TOr$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AOrBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AOrBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *);
extern struct _jc_soot_jimple_parser_node_TOr$object *_jc_soot_jimple_parser_node_AOrBinop$method$getOr$77baf9a5a4e12bba(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *);
extern void _jc_soot_jimple_parser_node_AOrBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AOrBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AOrBinop$method$setOr$8ae3364c28b4c394(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_TOr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AOrBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$getOr$77baf9a5a4e12bba;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$setOr$8ae3364c28b4c394;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AOrBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *);
	struct _jc_soot_jimple_parser_node_TOr$object	*(*getOr$77baf9a5a4e12bba)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setOr$8ae3364c28b4c394)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_TOr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AOrBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AOrBinop$vmethods	soot_jimple_parser_node_AOrBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AOrBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AOrBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AOrBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TOr$object	*__5for__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AOrBinop$refs {
    _jc_soot_jimple_parser_node_AOrBinop$sub_refs	soot_jimple_parser_node_AOrBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AOrBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AOrBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AOrBinop$sub_nonrefs	soot_jimple_parser_node_AOrBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AOrBinop$object {
	_jc_soot_jimple_parser_node_AOrBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AOrBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AOrBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AOrBinop$vtype _jc_soot_jimple_parser_node_AOrBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AOrBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AOrBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AOrBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AOrBinop.h <==
// public final class soot.jimple.parser.node.AOrBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 439434dedc6b9c37 soot_jimple_parser_node_AOrBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AOrBinop_H_
#define _JC_soot_jimple_parser_node_AOrBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TOr$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AOrBinop$sub_refs	_jc_soot_jimple_parser_node_AOrBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AOrBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AOrBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AOrBinop$refs	_jc_soot_jimple_parser_node_AOrBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AOrBinop$nonrefs	_jc_soot_jimple_parser_node_AOrBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AOrBinop$object	_jc_soot_jimple_parser_node_AOrBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AOrBinop$vmethods	_jc_soot_jimple_parser_node_AOrBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AOrBinop$vtable	_jc_soot_jimple_parser_node_AOrBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AOrBinop$vtype	_jc_soot_jimple_parser_node_AOrBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AOrBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AOrBinop$method$_init$a9a1f9f4adf55b94(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_TOr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AOrBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AOrBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TOr$object *_jc_soot_jimple_parser_node_AOrBinop$method$getOr$77baf9a5a4e12bba(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AOrBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AOrBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AOrBinop$method$setOr$8ae3364c28b4c394(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_TOr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AOrBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$getOr$77baf9a5a4e12bba;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$setOr$8ae3364c28b4c394;
extern _jc_method _jc_soot_jimple_parser_node_AOrBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AOrBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TOr$object	*(*getOr$77baf9a5a4e12bba)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setOr$8ae3364c28b4c394)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *, struct _jc_soot_jimple_parser_node_TOr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AOrBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AOrBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AOrBinop$vmethods	soot_jimple_parser_node_AOrBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AOrBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AOrBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AOrBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TOr$object	*__5for__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AOrBinop$refs {
    _jc_soot_jimple_parser_node_AOrBinop$sub_refs	soot_jimple_parser_node_AOrBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AOrBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AOrBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AOrBinop$sub_nonrefs	soot_jimple_parser_node_AOrBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AOrBinop$object {
	_jc_soot_jimple_parser_node_AOrBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AOrBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AOrBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AOrBinop$vtype _jc_soot_jimple_parser_node_AOrBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AOrBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AOrBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AOrBinop_H_ */
